@@ -1,5 +1,5 @@
 package PAR;
-$PAR::VERSION = '1.009';
+$PAR::VERSION = '1.011';
 
 use 5.006;
 use strict;
@@ -595,13 +595,12 @@ sub _first_member_matching {
 
 sub _run_member_from_par {
     my $member = shift;
-    my $clear_stack = shift;
     my ($fh, $is_new, $filename) = _tempfile($member->crc32String . ".pl");
 
     if ($is_new) {
         my $file = $member->fileName;
-        print $fh "package main;\n";
-        print $fh "#line 1 \"$file\"\n";
+        print $fh "package main;\n",
+                  "#line 1 \"$file\"\n";
         $member->extractToFileHandle($fh);
         seek ($fh, 0, 0);
     }
@@ -616,21 +615,25 @@ sub _run_member_from_par {
 
 sub _run_member {
     my $member = shift;
-    my $clear_stack = shift;
     my ($fh, $is_new, $filename) = _tempfile($member->crc32String . ".pl");
 
     if ($is_new) {
         my $file = $member->fileName;
-        print $fh "package main;\n";
-        if (defined &Internals::PAR::CLEARSTACK and $clear_stack) {
-            print $fh "Internals::PAR::CLEARSTACK();\n";
-        }
-        print $fh "#line 1 \"$file\"\n";
+        print $fh "package main;\n",
+                  "#line 1 \"$file\"\n";
         $member->extractToFileHandle($fh);
         seek ($fh, 0, 0);
     }
 
-    unshift @INC, sub { shift @INC; return $fh };
+    # NOTE: Perl 5.14.x will print the infamous warning
+    # "Use of uninitialized value in do "file" at .../PAR.pm line 636" 
+    # when $INC{main} exists, but is undef, when "do 'main'" is called.
+    # This typically happens at the second invocation of _run_member() 
+    # when running a packed executable (the first invocation is for the 
+    # generated script/main.pl, the second for the packed script itself). 
+    # Hence shut the warning up by assigning something to $INC{main}. 
+    # 5.14.x is the only Perl version since 5.8.1 that shows this behaviour.
+    unshift @INC, sub { shift @INC; $INC{$_[1]} = $filename; return $fh };
 
     $ENV{PAR_0} = $filename; # for Pod::Usage
     { do 'main';
@@ -642,17 +645,12 @@ sub _run_member {
 
 sub _run_external_file {
     my $filename = shift;
-    my $clear_stack = shift;
-    require 5.008;
     open my $ffh, '<', $filename
       or die "Can't open perl script \"$filename\": $!";
 
-    my $clearstack = '';
-    if (defined &Internals::PAR::CLEARSTACK and $clear_stack) {
-        $clear_stack = "Internals::PAR::CLEARSTACK();\n";
-    }
-    my $string = "package main;\n$clearstack#line 1 \"$filename\"\n"
-                 . do { local $/ = undef; <$ffh> };
+    my $string = "package main;\n" .
+                 "#line 1 \"$filename\"\n" .
+                 do { local $/ = undef; <$ffh> };
     close $ffh;
 
     open my $fh, '<', \$string
@@ -673,15 +671,14 @@ sub _run_external_file {
 # returns that directory.
 sub _extract_inc {
     my $file_or_azip_handle = shift;
-    my $force_extract = shift;
-    my $inc = "$PAR::SetupTemp::PARTemp/inc";
     my $dlext = defined($Config{dlext}) ? $Config::Config{dlext} : '';
-    my $inc_exists = -d $inc;
     my $is_handle = ref($file_or_azip_handle) && $file_or_azip_handle->isa('Archive::Zip::Archive');
 
     require File::Spec;
+    my $inc = File::Spec->catdir($PAR::SetupTemp::PARTemp, "inc");
+    my $canary = File::Spec->catfile($PAR::SetupTemp::PARTemp, $PAR::SetupTemp::Canary);
 
-    if (!$inc_exists or $force_extract) {
+    if (!-d $inc || !-e $canary) {
         for (1 .. 10) { mkdir("$inc.lock", 0755) and last; sleep 1 }
         
         undef $@;
@@ -725,9 +722,24 @@ sub _extract_inc {
               my $outfile =  File::Spec->catfile($inc, $_);
               next if -e $outfile and not -w _;
               $zip->extractMember($_, $outfile);
+              # Unfortunately Archive::Zip doesn't have an option
+              # NOT to restore member timestamps when extracting, hence set 
+              # it to "now" (making it younger than the canary file).
+              utime(undef, undef, $outfile);
           }
         }
         
+        # touch (and back-date) canary file
+        open my $fh, ">", $canary; 
+        print $fh <<'...';
+This file is used as "canary in the coal mine" to detect when 
+files in PAR's cache area are being removed by some clean up 
+mechanism (probably based on file modification times).
+...
+        close $fh;
+        my $dateback = time() - $PAR::SetupTemp::CanaryDateBack;
+        utime($dateback, $dateback, $canary);
+
         rmdir("$inc.lock");
 
         $ArchivesExtracted{$is_handle ? $file_or_azip_handle->fileName() : $file_or_azip_handle} = $inc;
@@ -1174,10 +1186,7 @@ __END__
 
 =head1 SEE ALSO
 
-The PAR homepage at L<http://par.perl.org>.
-
-L<PAR::Tutorial>, L<PAR::FAQ> (For a more
-current FAQ, refer to the homepage.)
+L<PAR::Tutorial>, L<PAR::FAQ> 
 
 The L<PAR::Packer> distribution which contains the packaging utilities:
 L<par.pl>, L<parl>, L<pp>.
@@ -1221,7 +1230,7 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 Steffen Mueller E<lt>smueller@cpan.orgE<gt>
 
-L<http://par.perl.org/> is the official PAR website.  You can write
+You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
 E<lt>par-subscribe@perl.orgE<gt> to participate in the discussion.
 
