@@ -76,7 +76,7 @@ sub _bootstrap {
     }
 
     my $member;
-    # First, try to find things in the peferentially loaded PARs:
+    # First, try to find things in the preferentially loaded PARs:
     $member = PAR::_find_par_internals([@PAR::PAR_INC], undef, $file, 1)
       if defined &PAR::_find_par_internals;
 
@@ -156,11 +156,9 @@ sub _dl_extract {
 
     if ($fh) {
         binmode($fh);
-        Archive::Zip::setErrorHandler(sub { die $_[0] });
         $member->extractToFileHandle($fh);
-        Archive::Zip::setErrorHandler(undef);
         close $fh;
-        chmod 0755, $filename;
+        chmod 0750, $filename;
     }
 
     return $filename;
@@ -176,7 +174,7 @@ L<PAR>
 
 Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
-L<http://par.perl.org/> is the official PAR website.  You can write
+You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
 E<lt>par-subscribe@perl.orgE<gt> to participate in the discussion.
 
